==> gnubg-release-1.06.002-sources.tar.gz: gnubg-1.06.002/gtktoolbar.h <==
/*
 * gtktoolbar.h
 *
 * by Joern Thyssen <jth@gnubg.org>, 2003
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 3 or later of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: gtktoolbar.h,v 1.15 2016/08/24 21:55:31 plm Exp $
 */

#ifndef GTKTOOLBAR_H
#define GTKTOOLBAR_H

#include "gtkboard.h"
#if !defined(USE_GTKUIMANAGER)
extern GtkItemFactory *pif;
#endif

typedef enum _toolbarcontrol {
    C_NONE,
    C_ROLLDOUBLE,
    C_TAKEDROP,
    C_AGREEDECLINE,
    C_PLAY
} toolbarcontrol;

extern GtkWidget *ToolbarNew(void);

extern toolbarcontrol
ToolbarUpdate(GtkWidget * pwToolbar,
              const matchstate * pms, const DiceShown diceShown, const int fComputerTurn, const int fPlaying);

extern int
 ToolbarIsEditing(GtkWidget * pwToolbar);

extern void
 ToolbarActivateEdit(GtkWidget * pwToolbar);

extern void
 ToolbarSetPlaying(GtkWidget * pwToolbar, const int f);

extern void
 ToolbarSetClockwise(GtkWidget * pwToolbar, const int f);

extern GtkWidget *image_from_xpm_d(char **xpm, GtkWidget * pw);

extern void click_edit(void);
extern void click_swapdirection(void);

#endif                          /* GTKTOOLBAR_H */

==> gnubg-release-1.08.002-sources.tar.gz: gnubg-1.08.002/gtktoolbar.h <==
/*
 * Copyright (C) 2003 Joern Thyssen <jth@gnubg.org>
 * Copyright (C) 2003-2011 the AUTHORS
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * $Id: gtktoolbar.h,v 1.17 2023/12/20 14:17:30 plm Exp $
 */

#ifndef GTKTOOLBAR_H
#define GTKTOOLBAR_H

#include "gtkboard.h"

#if defined(USE_GTKITEMFACTORY)
extern GtkItemFactory *pif;
#endif

typedef enum {
    C_NONE,
    C_ROLLDOUBLE,
    C_TAKEDROP,
    C_AGREEDECLINE,
    C_PLAY
} toolbarcontrol;

extern GtkWidget *ToolbarNew(void);

extern toolbarcontrol
ToolbarUpdate(GtkWidget * pwToolbar,
              const matchstate * pms, const DiceShown diceShown, const int fComputerTurn, const int fPlaying);

extern int
 ToolbarIsEditing(GtkWidget * pwToolbar);

extern void
 ToolbarActivateEdit(GtkWidget * pwToolbar);

extern void
 ToolbarSetPlaying(GtkWidget * pwToolbar, const int f);

extern void
 ToolbarSetClockwise(GtkWidget * pwToolbar, const int f);

extern GtkWidget *image_from_xpm_d(char **xpm, GtkWidget * pw);

extern void click_edit(void);
extern void click_swapdirection(void);

#endif                          /* GTKTOOLBAR_H */
